//go:build linux
// +build linux

package main

import (
	"errors"
	"testing"
)

func TestSetPin(t *testing.T) {
	ROOKPIN = "rookpintest"
	cases := []struct {
		data          []byte
		errorExpected bool
	}{
		{[]byte("1234"), false},
		{[]byte("5678"), false},
	}
	for _, tc := range cases {
		err := setPin(tc.data)
		if err == nil {
			if tc.errorExpected {
				t.Errorf("expected error; got none")
			}
		} else if !tc.errorExpected {
			t.Errorf("expected no error; got %v", err)
		}
	}
	// Need to clean up. Ignore errors.
	removePin()
}

func TestGetPin(t *testing.T) {
	ROOKPIN = "rookpintest"
	// Base case: no pin set
	v, e := getPin()
	if e != nil {
		if !errors.Is(e, ErrKeyNotFound{}) {
			t.Errorf("expected a ErrKeyNotFound; got %v", e)

		}
	} else {
		t.Errorf("expected a ErrKeyNotFound; got success")
	}
	if v != nil {
		t.Errorf("expected no key; got %s", string(v))
	}
	cases := []string{"1234", "5678"}
	for _, tc := range cases {
		expected := []byte(tc)
		err := setPin(expected)
		if err != nil {
			t.Errorf("expected no error; got %v", err)
		}
		rv, err := getPin()
		if err != nil {
			t.Errorf("expected no error; got %v", err)
		}
		if len(rv) != len(expected) {
			t.Errorf("expected %q; got %q", tc, string(rv))
		}
		for i, c := range rv {
			if c != expected[i] {
				t.Errorf("expected %q; got %q", tc, string(rv))
				break
			}
		}
	}
	// Need to clean up. Ignore errors.
	removePin()
}

func TestRemovePin(t *testing.T) {
	ROOKPIN = "rookpintest"
	// Base case: no pin set
	e := removePin()
	if e != nil {
		if !errors.Is(e, ErrKeyNotFound{}) {
			t.Errorf("expected a ErrKeyNotFound; got %v", e)

		}
	} else {
		t.Errorf("expected a ErrKeyNotFound; got success")
	}
	err := setPin([]byte("1234"))
	if err != nil {
		t.Errorf("expected no error; got %v", err)
	}
	err = removePin()
	if err != nil {
		t.Errorf("expected no error; got %v", err)
	}
	v, e := getPin()
	if e != nil {
		if !errors.Is(e, ErrKeyNotFound{}) {
			t.Errorf("expected a ErrKeyNotFound; got %v", e)

		}
	} else {
		t.Errorf("expected a ErrKeyNotFound; got success")
	}
	if v != nil {
		t.Errorf("expected no key; got %s", string(v))
	}
}
